<template>
    <div class="dialog-table-container">
        <el-table
            :element-loading-background="loadingColor"
            v-loading="loading"
            height="70vh"
            align="center"
            :data="tableData"
            class="dialog_table"
            :cell-style="{'text-align': 'center'}"
            :header-cell-style="{'text-align': 'center'}"
        >
            <el-table-column
                type="index"
                label="序号"
                width="60"
            ></el-table-column>
            <el-table-column
                prop="projectName"
                label="项目名称"
                width="320"
                align="left"
            >
            </el-table-column>
            <el-table-column prop="score" label="得分" width="100">
            </el-table-column>
            <el-table-column prop="allSn" label="排位"></el-table-column>
            <el-table-column prop="trend" label="变化">
                <template v-slot="{row}">
                    <span
                        :class="{
                            'column-item-rotate': row.trend < 0,
                        }"
                    >
                        <span v-if="row.trend == 0">-</span>
                        <i
                            v-if="row.trend > 0"
                            :class="`cqlt-icon cqlt-icon-arrow column-trend-icon-1`"
                        ></i>
                        <i
                            v-if="row.trend < 0"
                            :class="`cqlt-icon cqlt-icon-arrow column-trend-icon-2`"
                        ></i>
                    </span>
                </template>
            </el-table-column>
            <el-table-column prop="trend" label="操作">
                <template v-slot="{row}">
                    <el-tag
                        type="primary"
                        effect="dark"
                        style="cursor: pointer"
                        @click="openSubView(row)"
                        >进入分驾驶舱</el-tag
                    >
                </template>
            </el-table-column>
        </el-table>
    </div>
</template>

<script>
import apiList from '@/api/bigScreen/majorView.js'
export default {
    name: 'indexRank',
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            tableData: [],
        }
    },
    mounted() {
        this.loadData()
    },
    methods: {
        openSubView(item) {
            this.$router.push(
                '/MajorProjectsSubView?projectId=' + item.projectId
            )
        },
        // 改革品牌榜
        loadData() {
            this.loading = true
            apiList.getRank(
                this.qs.stringify({
                    type: 'composite',
                    year: this.year,
                    month: this.month,
                }),
                (res) => {
                    if (res && res.value) {
                        this.tableData = res.value
                    }
                    this.loading = false
                }
            )
        },
    },
}
</script>
<style lang="scss" scoped>
.column-item-rotate {
  display: inline-block;
  transform: rotateX(180deg);
}

.cqlt-icon-arrow {
  font-size: 18px;
}

.column-trend-icon-1 {
  color: #59c06c;
  text-shadow: #59c06c 1px 0 12px;
}

.column-trend-icon-2 {
  color: #fe3b30;
  text-shadow: #fe3b30 1px 0 12px;
}
</style>
<style lang="scss">
@import './table.scss';
</style>
